novident_editor_flutter library
Classes
- LineMetrics
- LineMetrics stores the measurements and statistics of a single line in the paragraph.
- RenderParagraph
- A render object that displays a paragraph of text.
- RichText
- A paragraph of rich text.
- TextPainter
- An object that paints a TextSpan tree into a Canvas.
- TextRange
- A range of characters in a string of text.
- TextSelection
- A range of text that represents a selection.
- WordBoundary
- A TextBoundary subclass for locating word breaks.
Constants
- kDefaultFontSize → const double
- The default font size if none is specified.